﻿using Hotline.Orders;
using Hotline.Share.Dtos.Snapshot;
using Hotline.Share.Tools;
using Hotline.Snapshot;
using Hotline.Snapshot.Interfaces;
using Mapster;
using Microsoft.Extensions.Logging;
using Newtonsoft.Json;
using Renci.SshNet;
using System.Net.Http.Headers;
using System.Text;
using TianQue.Sdk.Models;
using XF.Domain.Dependency;

namespace TianQue.Sdk;

public class TiqnQueService : IGuiderSystemService, IScopeDependency
{
    private readonly ILogger<TQHttpClient> _logger;
    private readonly string _url = "http://10.0.188.11:6090/api/v1/test/accept/saveAcceptInfoApi";

    public TiqnQueService(ILogger<TQHttpClient> logger)
    {
        _logger = logger;
    }

    public async Task<string> PostOrder(Order order, OrderSnapshot orderSnapshot, ThirdTokenDto tokenDto)
    {
        TQHttpClient httpClient;
#if DEBUG
         httpClient = new TQHttpClient(tokenDto.Secret, tokenDto.AppId, "171.94.154.2", 22, "root" , "ZGbyy@2024!", _logger);
#else
         httpClient = new TQHttpClient(tokenDto.Secret, tokenDto.AppId, _logger);
#endif
        var acceptInfo = order.Adapt<AcceptInfo>();
        acceptInfo.ReplyCode = order.No!; // 唯一标识
        acceptInfo.TypeName = order.AcceptType!; // 诉求类型名称
        acceptInfo.OccurDate = order.CreationTime; // 事发时间
        //acceptInfo.OccurDate = DateTime.Now; // 事发时间
        acceptInfo.DetailAddress = order.FullAddress!; // 详细地址
        acceptInfo.Topic = order.Title!; // 线索主题
        acceptInfo.DetailContent = order.Content!; // 详细内容
        acceptInfo.Lon = order.Longitude.ToString(); // 经度
        acceptInfo.Lat = order.Latitude.ToString(); // 纬度
        acceptInfo.RootCategoryInfo = ""; // order.HotspotName!; // 热点分类(大类)
        acceptInfo.CategoryInfo = "";// order.HotspotSpliceName!; // 热点分类(小类)
        acceptInfo.DeadLine = orderSnapshot.DeadLine!.Value; // 截止时间
        acceptInfo.Prod = false; // 正式/测试

        // 反映人信息
        acceptInfo.PersonList = new List<PersonInfo>
        {
            new() {
                // ReflectCardId = // 反映人身份证号
                ReflectPhone = order.Contact!, // 电话
                ReflectUserName = order.FromName!, // 姓名
            } 
        };
        var result = await httpClient.PostAsync<ApiReponse<AcceptInfoSuccessDto>>(new Uri(_url), acceptInfo);
        return result.ToJson();
    }
}
